Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(8585)

Unified Diff: chrome/browser/extensions/extension_system_impl.cc

Issue 2807683003: Prevent loading of session extensions into the sign-in profile (Closed)
Patch Set: Fix the condition Created 3 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/browser/chromeos/file_manager/file_manager_browsertest_base.cc ('k') | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/extensions/extension_system_impl.cc
diff --git a/chrome/browser/extensions/extension_system_impl.cc b/chrome/browser/extensions/extension_system_impl.cc
index ddaf85214ebd97e6b17fb672e8e6977095387042..ff266fc77a02b1e3cbd52d42bc25eb5a3bbfb08e 100644
--- a/chrome/browser/extensions/extension_system_impl.cc
+++ b/chrome/browser/extensions/extension_system_impl.cc
@@ -244,8 +244,10 @@ void ExtensionSystemImpl::Shared::Init(bool extensions_enabled) {
bool skip_session_extensions = false;
#if defined(OS_CHROMEOS)
- // Skip loading session extensions if we are not in a user session.
- skip_session_extensions = !chromeos::LoginState::Get()->IsUserLoggedIn();
+ // Skip loading session extensions if we are not in a user session or if the
+ // profile is the sign-in profile, which doesn't correspond to a user session.
+ skip_session_extensions = !chromeos::LoginState::Get()->IsUserLoggedIn() ||
+ chromeos::ProfileHelper::IsSigninProfile(profile_);
Devlin 2017/04/10 15:40:54 It's surprising to me that the user can be logged
emaxx 2017/04/11 12:12:36 I think the sign-in profile (and the initial profi
if (chrome::IsRunningInForcedAppMode()) {
extension_service_->component_loader()->
AddDefaultComponentExtensionsForKioskMode(skip_session_extensions);
« no previous file with comments | « chrome/browser/chromeos/file_manager/file_manager_browsertest_base.cc ('k') | no next file » | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698